# Introduction

```{todo}
flesh this out.
```

```{note}
Torii-USB is still a work in progress; and while much of the technology is in a usable state,
much of its feature-set is still being built. Consider Torii-USB an 'unstable' library, for the time being.
```

Welcome to the Torii-USB project! Torii-USB is a full toolkit for working with USB using FPGAs, it provides a gateware library to implement USB in your own Torii based designs.

Some things you can use Torii-USB for, currently:

- **Creating your own Low, Full or High speed USB device.** Torii-USB provides a collection of Torii gateware that
  allows you to easily create USB devices in gateware, software, or a combination of the two.

More detail on these features is covered in [the source], and in the remainder of this documentation.

[the source]: https://github.com/shrine-maiden-heavy-industries/torii-usb
